@@ -4,15 +4,10 @@ require 'time'
 
 require 'tzinfo'
 
+require 'et-orbi/version'
 require 'et-orbi/info'
 require 'et-orbi/make'
 require 'et-orbi/time'
 require 'et-orbi/zones'
 require 'et-orbi/zone'
 
-
-module EtOrbi
-
-  VERSION = '1.2.7'
-end
-
